==> knative-model-5.1.2-sources.jar: io/fabric8/knative/sources/v1beta1/SinkBindingSpecFluentImpl.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluentImpl;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesBuilder;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl;

public class SinkBindingSpecFluentImpl<A extends SinkBindingSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SinkBindingSpecFluent<A> {

    private CloudEventOverridesBuilder ceOverrides;
    private DestinationBuilder sink;
    private ReferenceBuilder subject;

    public SinkBindingSpecFluentImpl() {
    }

    public SinkBindingSpecFluentImpl(SinkBindingSpec instance) {
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withSink(instance.getSink()); 
        this.withSubject(instance.getSubject()); 
    }

    
/**
 * This method has been deprecated, please use method buildCeOverrides instead.
 * @return The buildable object.
 */
@Deprecated public CloudEventOverrides getCeOverrides() {
        return this.ceOverrides!=null?this.ceOverrides.build():null;
    }

    public CloudEventOverrides buildCeOverrides() {
        return this.ceOverrides!=null?this.ceOverrides.build():null;
    }

    public A withCeOverrides(CloudEventOverrides ceOverrides) {
        _visitables.get("ceOverrides").remove(this.ceOverrides);
        if (ceOverrides!=null){ this.ceOverrides= new CloudEventOverridesBuilder(ceOverrides); _visitables.get("ceOverrides").add(this.ceOverrides);} return (A) this;
    }

    public Boolean hasCeOverrides() {
        return this.ceOverrides != null;
    }

    public SinkBindingSpecFluent.CeOverridesNested<A> withNewCeOverrides() {
        return new CeOverridesNestedImpl();
    }

    public SinkBindingSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item) {
        return new CeOverridesNestedImpl(item);
    }

    public SinkBindingSpecFluent.CeOverridesNested<A> editCeOverrides() {
        return withNewCeOverridesLike(getCeOverrides());
    }

    public SinkBindingSpecFluent.CeOverridesNested<A> editOrNewCeOverrides() {
        return withNewCeOverridesLike(getCeOverrides() != null ? getCeOverrides(): new CloudEventOverridesBuilder().build());
    }

    public SinkBindingSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item) {
        return withNewCeOverridesLike(getCeOverrides() != null ? getCeOverrides(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink() {
        return this.sink!=null?this.sink.build():null;
    }

    public Destination buildSink() {
        return this.sink!=null?this.sink.build():null;
    }

    public A withSink(Destination sink) {
        _visitables.get("sink").remove(this.sink);
        if (sink!=null){ this.sink= new DestinationBuilder(sink); _visitables.get("sink").add(this.sink);} return (A) this;
    }

    public Boolean hasSink() {
        return this.sink != null;
    }

    public SinkBindingSpecFluent.SinkNested<A> withNewSink() {
        return new SinkNestedImpl();
    }

    public SinkBindingSpecFluent.SinkNested<A> withNewSinkLike(Destination item) {
        return new SinkNestedImpl(item);
    }

    public SinkBindingSpecFluent.SinkNested<A> editSink() {
        return withNewSinkLike(getSink());
    }

    public SinkBindingSpecFluent.SinkNested<A> editOrNewSink() {
        return withNewSinkLike(getSink() != null ? getSink(): new DestinationBuilder().build());
    }

    public SinkBindingSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item) {
        return withNewSinkLike(getSink() != null ? getSink(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public Reference getSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public Reference buildSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public A withSubject(Reference subject) {
        _visitables.get("subject").remove(this.subject);
        if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} return (A) this;
    }

    public Boolean hasSubject() {
        return this.subject != null;
    }

    public SinkBindingSpecFluent.SubjectNested<A> withNewSubject() {
        return new SubjectNestedImpl();
    }

    public SinkBindingSpecFluent.SubjectNested<A> withNewSubjectLike(Reference item) {
        return new SubjectNestedImpl(item);
    }

    public SinkBindingSpecFluent.SubjectNested<A> editSubject() {
        return withNewSubjectLike(getSubject());
    }

    public SinkBindingSpecFluent.SubjectNested<A> editOrNewSubject() {
        return withNewSubjectLike(getSubject() != null ? getSubject(): new ReferenceBuilder().build());
    }

    public SinkBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(Reference item) {
        return withNewSubjectLike(getSubject() != null ? getSubject(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SinkBindingSpecFluentImpl that = (SinkBindingSpecFluentImpl) o;
        if (ceOverrides != null ? !ceOverrides.equals(that.ceOverrides) :that.ceOverrides != null) return false;
        if (sink != null ? !sink.equals(that.sink) :that.sink != null) return false;
        if (subject != null ? !subject.equals(that.subject) :that.subject != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(ceOverrides,  sink,  subject,  super.hashCode());
    }

    public class CeOverridesNestedImpl<N> extends CloudEventOverridesFluentImpl<SinkBindingSpecFluent.CeOverridesNested<N>> implements SinkBindingSpecFluent.CeOverridesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final CloudEventOverridesBuilder builder;

            CeOverridesNestedImpl(CloudEventOverrides item) {
                this.builder = new CloudEventOverridesBuilder(this, item);
                        
            }

            CeOverridesNestedImpl() {
                this.builder = new CloudEventOverridesBuilder(this);
                        
            }

            public N and() {
                return (N) SinkBindingSpecFluentImpl.this.withCeOverrides(builder.build());
            }

            public N endCeOverrides() {
                return and();
            }
    }


    public class SinkNestedImpl<N> extends DestinationFluentImpl<SinkBindingSpecFluent.SinkNested<N>> implements SinkBindingSpecFluent.SinkNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final DestinationBuilder builder;

            SinkNestedImpl(Destination item) {
                this.builder = new DestinationBuilder(this, item);
                        
            }

            SinkNestedImpl() {
                this.builder = new DestinationBuilder(this);
                        
            }

            public N and() {
                return (N) SinkBindingSpecFluentImpl.this.withSink(builder.build());
            }

            public N endSink() {
                return and();
            }
    }


    public class SubjectNestedImpl<N> extends ReferenceFluentImpl<SinkBindingSpecFluent.SubjectNested<N>> implements SinkBindingSpecFluent.SubjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ReferenceBuilder builder;

            SubjectNestedImpl(Reference item) {
                this.builder = new ReferenceBuilder(this, item);
                        
            }

            SubjectNestedImpl() {
                this.builder = new ReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) SinkBindingSpecFluentImpl.this.withSubject(builder.build());
            }

            public N endSubject() {
                return and();
            }
    }


}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/sources/v1beta1/SinkBindingSpecFluentImpl.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.knative.internal.pkg.tracker.Reference;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluentImpl;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesBuilder;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluentImpl;

public class SinkBindingSpecFluentImpl<A extends SinkBindingSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SinkBindingSpecFluent<A> {

    private CloudEventOverridesBuilder ceOverrides;
    private DestinationBuilder sink;
    private ReferenceBuilder subject;

    public SinkBindingSpecFluentImpl() {
    }

    public SinkBindingSpecFluentImpl(SinkBindingSpec instance) {
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withSink(instance.getSink()); 
        this.withSubject(instance.getSubject()); 
    }

    
/**
 * This method has been deprecated, please use method buildCeOverrides instead.
 * @return The buildable object.
 */
@Deprecated public CloudEventOverrides getCeOverrides() {
        return this.ceOverrides!=null?this.ceOverrides.build():null;
    }

    public CloudEventOverrides buildCeOverrides() {
        return this.ceOverrides!=null?this.ceOverrides.build():null;
    }

    public A withCeOverrides(CloudEventOverrides ceOverrides) {
        _visitables.get("ceOverrides").remove(this.ceOverrides);
        if (ceOverrides!=null){ this.ceOverrides= new CloudEventOverridesBuilder(ceOverrides); _visitables.get("ceOverrides").add(this.ceOverrides);} return (A) this;
    }

    public Boolean hasCeOverrides() {
        return this.ceOverrides != null;
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<A> withNewCeOverrides() {
        return new CeOverridesNestedImpl();
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item) {
        return new CeOverridesNestedImpl(item);
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<A> editCeOverrides() {
        return withNewCeOverridesLike(getCeOverrides());
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<A> editOrNewCeOverrides() {
        return withNewCeOverridesLike(getCeOverrides() != null ? getCeOverrides(): new CloudEventOverridesBuilder().build());
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item) {
        return withNewCeOverridesLike(getCeOverrides() != null ? getCeOverrides(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink() {
        return this.sink!=null?this.sink.build():null;
    }

    public Destination buildSink() {
        return this.sink!=null?this.sink.build():null;
    }

    public A withSink(Destination sink) {
        _visitables.get("sink").remove(this.sink);
        if (sink!=null){ this.sink= new DestinationBuilder(sink); _visitables.get("sink").add(this.sink);} return (A) this;
    }

    public Boolean hasSink() {
        return this.sink != null;
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<A> withNewSink() {
        return new SinkNestedImpl();
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<A> withNewSinkLike(Destination item) {
        return new SinkNestedImpl(item);
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<A> editSink() {
        return withNewSinkLike(getSink());
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<A> editOrNewSink() {
        return withNewSinkLike(getSink() != null ? getSink(): new DestinationBuilder().build());
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item) {
        return withNewSinkLike(getSink() != null ? getSink(): item);
    }

    
/**
 * This method has been deprecated, please use method buildSubject instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.internal.pkg.tracker.Reference getSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public io.fabric8.knative.internal.pkg.tracker.Reference buildSubject() {
        return this.subject!=null?this.subject.build():null;
    }

    public A withSubject(io.fabric8.knative.internal.pkg.tracker.Reference subject) {
        _visitables.get("subject").remove(this.subject);
        if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} return (A) this;
    }

    public Boolean hasSubject() {
        return this.subject != null;
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<A> withNewSubject() {
        return new SubjectNestedImpl();
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<A> withNewSubjectLike(io.fabric8.knative.internal.pkg.tracker.Reference item) {
        return new SubjectNestedImpl(item);
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<A> editSubject() {
        return withNewSubjectLike(getSubject());
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<A> editOrNewSubject() {
        return withNewSubjectLike(getSubject() != null ? getSubject(): new ReferenceBuilder().build());
    }

    public io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<A> editOrNewSubjectLike(io.fabric8.knative.internal.pkg.tracker.Reference item) {
        return withNewSubjectLike(getSubject() != null ? getSubject(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        SinkBindingSpecFluentImpl that = (SinkBindingSpecFluentImpl) o;
        if (ceOverrides != null ? !ceOverrides.equals(that.ceOverrides) :that.ceOverrides != null) return false;
        if (sink != null ? !sink.equals(that.sink) :that.sink != null) return false;
        if (subject != null ? !subject.equals(that.subject) :that.subject != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(ceOverrides,  sink,  subject,  super.hashCode());
    }

    public class CeOverridesNestedImpl<N> extends CloudEventOverridesFluentImpl<io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<N>> implements io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.CeOverridesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final CloudEventOverridesBuilder builder;

            CeOverridesNestedImpl(CloudEventOverrides item) {
                this.builder = new CloudEventOverridesBuilder(this, item);
                        
            }

            CeOverridesNestedImpl() {
                this.builder = new CloudEventOverridesBuilder(this);
                        
            }

            public N and() {
                return (N) SinkBindingSpecFluentImpl.this.withCeOverrides(builder.build());
            }

            public N endCeOverrides() {
                return and();
            }
    }


    public class SinkNestedImpl<N> extends DestinationFluentImpl<io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<N>> implements io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SinkNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final DestinationBuilder builder;

            SinkNestedImpl(Destination item) {
                this.builder = new DestinationBuilder(this, item);
                        
            }

            SinkNestedImpl() {
                this.builder = new DestinationBuilder(this);
                        
            }

            public N and() {
                return (N) SinkBindingSpecFluentImpl.this.withSink(builder.build());
            }

            public N endSink() {
                return and();
            }
    }


    public class SubjectNestedImpl<N> extends ReferenceFluentImpl<io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<N>> implements io.fabric8.knative.sources.v1beta1.SinkBindingSpecFluent.SubjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ReferenceBuilder builder;

            SubjectNestedImpl(io.fabric8.knative.internal.pkg.tracker.Reference item) {
                this.builder = new ReferenceBuilder(this, item);
                        
            }

            SubjectNestedImpl() {
                this.builder = new ReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) SinkBindingSpecFluentImpl.this.withSubject(builder.build());
            }

            public N endSubject() {
                return and();
            }
    }


}
